@@ -48,8 +48,13 @@ def plot_cross(out, title='', fontsize=12, figsize=(15, 8)):
     # Make figure
     fig, ax = plt.subplots(figsize=figsize)
     # Plot each ROC
+    get_auc=[]
     for i, key in enumerate(out.keys()):
-        ax = ROC.plot(out.get(key), label=str(key), color=colors[i,:], ax=ax)
+        ax = ROC.plot(out.get(key), label=str(key), color=colors[i,:], ax=ax, title=title, fontsize=fontsize)
+        get_auc.append(out.get(key)['auc'])
+    
+    # Set title
+    ax.set_title(label=title + ('\nMean AUC: %.3f' %(np.mean(get_auc))), fontsize=fontsize)
 
     return fig, ax
 
@@ -144,18 +149,18 @@ def eval(y_true, y_proba, y_score=None, y_pred=None, pos_label=None, threshold=0
     if pos_label is not None:
         if not np.any(y_true==pos_label):
             raise Exception(['[classeval] pos_label is not found in y_true!'])
-    if (pos_label is None) and (y_true.dtype!='bool') and (len(np.unique(y_true))<=2):
-        raise Exception('[classeval] eval should have input argument <pos_label> or <y_true> being of type bool.')
+    # if (pos_label is None) and (y_true.dtype!='bool') and (len(np.unique(y_true))<=2):
+        # raise Exception('[classeval] eval should have input argument <pos_label> or <y_true> being of type bool.')
 
     # Create classification report
     class_names = np.unique(y_true)
     if len(class_names)==2:
         if len(np.shape(y_proba))>1:
-            print('[classeval] In two class evaluation, it is only recomended to specify <y_proba> of interest. The first column is now taken as input.')
+            print('[classeval] Warning >In two class evaluation, it is only recomended to specify <y_proba> of interest. The first column is now taken as input.')
             y_proba = y_proba[:,0]
         if pos_label is None:
-            print('[classeval] In two class evaluation, it is recomended to specify <pos_label>.')
             pos_label = np.unique(y_true)[0]
+            print('[classeval] >Warning In two class evaluation, it is recomended to specify <pos_label>. pos_label is set to "%s"' %(pos_label))
         out = eval_twoclass(y_true, y_proba, threshold=threshold, pos_label=pos_label, normalize=normalize, verbose=verbose)
     elif len(class_names)>2:
         out = eval_multiclass(y_true, y_proba, y_score, y_pred, normalize=normalize, verbose=verbose)
